//  PerlMsg.rc
//  The Win32::EventLog::Message resource file.
//  (c) Dave Roth
//  Courtesy of Roth Consulting
//  http://www.roth.net/
//
//  2000.06.12

#include "PerlMsg.h"
#include "version.h"

#define APSTUDIO_READONLY_SYMBOLS
/////////////////////////////////////////////////////////////////////////////
//
// Generated from the TEXTINCLUDE 2 resource.
//
#include "afxres.h"

/////////////////////////////////////////////////////////////////////////////
#undef APSTUDIO_READONLY_SYMBOLS


#ifdef _WIN32
LANGUAGE LANG_ENGLISH, SUBLANG_ENGLISH_US
#pragma code_page(1252)
#endif //_WIN32

/////////////////////////////////////////////////////////////////////////////
//
// Icon
//
// Icon with lowest ID value placed first to ensure application icon
// remains consistent on all systems.
#define IDI_ICON                    100    
IDI_ICON    ICON    DISCARDABLE     "PerlMsg.ico"


/////////////////////////////////////////////////////////////////////////////
//
// Version
//
VS_VERSION_INFO VERSIONINFO
 FILEVERSION    MESSAGE_FILE_VERSION_MAJOR_HI, MESSAGE_FILE_VERSION_MAJOR_LO, MESSAGE_FILE_VERSION_MINOR_HI, MESSAGE_FILE_VERSION_MINOR_LO
 PRODUCTVERSION MESSAGE_PRODUCT_VESION_MAJOR_HI, MESSAGE_PRODUCT_VERSION_MAJOR_LO, MESSAGE_PRODUCT_VERSION_MINOR_HI, MESSAGE_PRODUCT_VERSION_MINOR_LO
 FILEFLAGSMASK 0x3fL
#ifdef _DEBUG
 FILEFLAGS 0x1L
#else
 FILEFLAGS 0x0L
#endif
 FILEOS 0x40004L
 FILETYPE 0x2L
 FILESUBTYPE 0x0L
BEGIN
    BLOCK "StringFileInfo"
    BEGIN
        BLOCK "040904b0"
        BEGIN
            VALUE "Comments",           MESSAGE_PRODUCT_COMMENT_ANSI "\0"
            VALUE "CompanyName",        MESSAGE_COMPANY_NAME_ANSI "\0"
            VALUE "FileDescription",    MESSAGE_PRODUCT_NAME_ANSI "\0"
            VALUE "FileVersion",        MESSAGE_PRODUCT_VERSION_ANSI "\0"
            VALUE "InternalName",       MESSAGE_PRODUCT_NICKNAME_ANSI "\0"
            VALUE "LegalCopyright",     "Copyright © " MESSAGE_PRODUCT_COPYRIGHT_YEAR_ANSI " by " MESSAGE_COMPANY_NAME_ANSI "\0"
            VALUE "LegalTrademarks",    "\0"
            VALUE "OriginalFilename",   MESSAGE_FILTER_FILE_NAME_ANSI "\0"
            VALUE "PrivateBuild",       "\0"
            VALUE "ProductName",        MESSAGE_PRODUCT_NAME_FULL_ANSI "\0"
            VALUE "ProductVersion",     MESSAGE_PRODUCT_VERSION_ANSI "\0"
            VALUE "SpecialBuild",       "\0"
        END
    END
    BLOCK "VarFileInfo"
    BEGIN
        VALUE "Translation", 0x409, 1200
    END
END




LANGUAGE 0x9,0x0
1 11 MSG0001.bin


